@@ -35,9 +35,6 @@ spAR.Gibbs<-function(formula, data=parent.frame(), time.data, coords,
     if ( !is.matrix(coords) ) {
          stop("\n Error: coords must be a (n x 2) matrix of xy-coordinate locations \n")
     }
-    if ( (!is.numeric(coords[,1])) | (!is.numeric(coords[,2]))) {
-         stop("\n Error: coords columns should be numeric \n")
-    }
    #
      method <- distance.method
      spT.check.sites.inside(coords, method)
@@ -372,9 +369,6 @@ spAR.Gibbs<-function(formula, data=parent.frame(), time.data, coords,
         if (!is.matrix(pred.coords)) {
            stop("Error: prediction coords must be a (n x 2) matrix of xy-coordinate locations.")
         }
-        if ( (!is.numeric(pred.coords[,1])) | (!is.numeric(pred.coords[,2]))) {
-           stop("\n Error: prediction coords columns should be numeric \n")
-        }
       #
            coords.all <- rbind(coords,pred.coords)
            spT.check.locations(coords, pred.coords, method, tol=tol.dist)
@@ -573,9 +567,6 @@ spAR.Gibbs<-function(formula, data=parent.frame(), time.data, coords,
        if ( !is.matrix(fore.coords) ) {
          stop("\n# Error: fore.coords must be a matrix of xy-coordinate locations")
        }
-       if ( (!is.numeric(fore.coords[,1])) | (!is.numeric(fore.coords[,2]))) {
-         stop("\n Error: fore.coords columns should be numeric \n")
-       }
       #
       #
            n <- posteriors$n
@@ -728,9 +719,16 @@ pred.samples<-log(pred.samples.ar$pred.samples[,])
           # 
       out<-NULL
       # output$n.fore.sites <- nsite
+      #output$foreStep <- K
       output$fore.coords <- fore.coords
       output$distance.method<-posteriors$distance.method  
       output$cov.fnc<-posteriors$cov.fnc  
+      output$obsData<-matrix(posteriors$Y,r*T,n)  
+      output$fittedData<-matrix(posteriors$fitted[,1],r*T,n) 
+      if(posteriors$scale.transform=="SQRT"){output$fittedData<-output$fittedData^2}
+      else if(posteriors$scale.transform=="LOG"){output$fittedData<-exp(output$fittedData)}
+      else {output$fittedData<-output$fittedData}
+      output$residuals<-matrix(c(output$obsData)-c(output$fittedData),r*T,n)
       #
       if(Summary == TRUE){
          if(itt < 40){
@@ -831,10 +829,7 @@ spAR.MCMC.Pred<-function(formula, data=parent.frame(), time.data,
     }
     else {
        coords.D <- as.matrix(dist(coords, method, diag = T, upper = T))
-    }
-    if ( (!is.numeric(coords[,1])) | (!is.numeric(coords[,2]))) {
-         stop("\n Error: coords columns should be numeric \n")
-    }
+    }  
    #
    # check time.data
    if(is.null(time.data)){
@@ -968,9 +963,6 @@ spAR.MCMC.Pred<-function(formula, data=parent.frame(), time.data,
         if (!is.matrix(pred.coords)) {
            stop("Error: prediction coords must be a (n x 2) matrix of xy-coordinate locations.")
         }
-        if ( (!is.numeric(pred.coords[,1])) | (!is.numeric(pred.coords[,2]))) {
-           stop("\n Error: prediction coords columns should be numeric \n")
-        }
       #
       #
       #  if (is.null(pred.X)){
